@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2020, Raffaele Salmaso <raffaele@salmaso.org>
+# Copyright (C) 2007-2022, Raffaele Salmaso <raffaele@salmaso.org>
 # Copyright (c) 2015 S-Block
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -19,6 +19,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
+from __future__ import annotations
+
 from django import forms
 from django.conf import settings
 from django.contrib.admin import helpers
@@ -28,9 +30,8 @@ from django.core.exceptions import FieldDoesNotExist, PermissionDenied
 from django.db import models, transaction
 from django.forms.formsets import all_valid
 from django.http import Http404
-from django.templatetags.static import static
 from django.utils.decorators import method_decorator
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.html import escape
 from django.utils.translation import gettext as _
 from django.views.decorators.csrf import csrf_protect
@@ -68,8 +69,12 @@ class InlineInstancesMixin:
 class NestedModelAdmin(InlineInstancesMixin, ModelAdmin):
     @property
     def media(self):
-        css = {"all": [static("fluo/admin/css/forms-nested.css")]}
-        js = [static(f"fluo/admin/js/inlines-nested{'' if settings.DEBUG else '.min'}.js")]
+        media = super().media
+        css = media._css
+        css["all"] = css.get("all", []).append("fluo/admin/css/forms-nested.css")
+        js = media._js + [
+            f"fluo/admin/js/inlines-nested{'' if settings.DEBUG else '.min'}.js",
+        ]
         return forms.Media(css=css, js=js)
 
     def save_formset(self, request, form, formset, change):
@@ -289,7 +294,7 @@ class NestedModelAdmin(InlineInstancesMixin, ModelAdmin):
 
         context = {
             **self.admin_site.each_context(request),
-            "title": _("Add %s") % force_text(opts.verbose_name),
+            "title": _("Add %s") % force_str(opts.verbose_name),
             "adminform": adminForm,
             "is_popup": "_popup" in request.GET,
             "show_delete": False,
@@ -316,7 +321,7 @@ class NestedModelAdmin(InlineInstancesMixin, ModelAdmin):
         if obj is None:
             raise Http404(
                 _("%(name)s object with primary key %(key)r does not exist.")
-                % {"name": force_text(opts.verbose_name), "key": escape(object_id)},
+                % {"name": force_str(opts.verbose_name), "key": escape(object_id)},
             )
 
         if request.method == "POST" and "_saveasnew" in request.POST:
@@ -407,7 +412,7 @@ class NestedModelAdmin(InlineInstancesMixin, ModelAdmin):
 
         context = {
             **self.admin_site.each_context(request),
-            "title": _("Change %s") % force_text(opts.verbose_name),
+            "title": _("Change %s") % force_str(opts.verbose_name),
             "adminform": adminForm,
             "object_id": object_id,
             "original": obj,
@@ -427,7 +432,10 @@ class NestedInline(InlineInstancesMixin, InlineModelAdmin):
 
     @property
     def media(self):
-        js = [static(f"fluo/admin/js/inlines-nested{'' if settings.DEBUG else '.min'}.js")]
+        media = super().media
+        js = media._js + [
+            f"fluo/admin/js/inlines-nested{'' if settings.DEBUG else '.min'}.js",
+        ]
         return forms.Media(js=js)
 
     def get_formsets_with_inlines(self, request, obj=None):
